# OrzTinyPNG

This is a simple example package. You can use

## Usage

```bash
$ pip install OrzTinyPNG
$ tiny -h
```

[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

# How to Publish

[publish tutorial](https://packaging.python.org/tutorials/packaging-projects/)

# Choose you license

[Choose a License for your self](https://choosealicense.com)

# 参考

- [TinyPNG 官网](https://tinypng.com/)
- [TinyPNG API Key](https://tinypng.com/developers)
- [TinyPNG API Ref](https://tinypng.com/developers/reference)
- [TinyPNG Python API Doc](https://tinypng.com/developers/reference/python)
